===========
queryfilter
===========

.. image:: https://travis-ci.org/iCHEF/queryfilter.svg?branch=master
  :target: https://travis-ci.org/iCHEF/queryfilter


Feature
=======

- Allow same query interface to be shared between Django ORM, SQLAlchemy, and GraphQL backend.


Document
========

https://github.com/iCHEF/queryfilter/wiki

Installation
============

.. code-block::

  pip install queryfilter


Development
===========

.. code-block::

  git clone https://github.com/iCHEF/queryfilter.git
  cd queryfilter
  pip install -e .[dev]



Tests
-----

This project uses `pytest <http://pytest.org>`_ to run tests.
